# Enabling Visual Observations

## The `*_visual` Environment Variant

All environments have a `*_visual` variant that differs in the enabled sensors, namely cameras that provide visual observations at the cost of increased computational requirements.

```bash
.docker/run.bash scripts/teleop.py --task sample_collection_visual
```
